aboutsummaryrefslogtreecommitdiffhomepage
path: root/src/effects
diff options
context:
space:
mode:
authorGravatar senorblanco@chromium.org <senorblanco@chromium.org@2bbb7eff-a529-9590-31e7-b0007b416f81>2013-01-10 19:55:18 +0000
committerGravatar senorblanco@chromium.org <senorblanco@chromium.org@2bbb7eff-a529-9590-31e7-b0007b416f81>2013-01-10 19:55:18 +0000
commit171f5c76b95da85ff7341f6cb0dcdac868101de7 (patch)
treefee75eb22917ad669e98580b7bf4acb301bc605c /src/effects
parent091f51b794e62942db47ccef6fef143ad1590d12 (diff)
Rename onFilterImageGPU to filterImageGPU(), to match skia convention. No change in functionality.
(Note that this does mean that clients must override onFilterImage() to implement the raster path, but filterImageGPU() to implement the GPU path.) Review URL: https://codereview.appspot.com/7058078 git-svn-id: http://skia.googlecode.com/svn/trunk@7123 2bbb7eff-a529-9590-31e7-b0007b416f81
Diffstat (limited to 'src/effects')
-rw-r--r--src/effects/SkBlendImageFilter.cpp6
-rw-r--r--src/effects/SkBlurImageFilter.cpp2
-rw-r--r--src/effects/SkMorphologyImageFilter.cpp4
-rw-r--r--src/effects/SkSingleInputImageFilter.cpp4
4 files changed, 8 insertions, 8 deletions
diff --git a/src/effects/SkBlurImageFilter.cpp b/src/effects/SkBlurImageFilter.cpp
index fb76269823..38111d0fbd 100644
--- a/src/effects/SkBlurImageFilter.cpp
+++ b/src/effects/SkBlurImageFilter.cpp
@@ -187,7 +187,7 @@ bool SkBlurImageFilter::onFilterImage(Proxy* proxy,
return true;
}
-GrTexture* SkBlurImageFilter::onFilterImageGPU(Proxy* proxy, GrTexture* src, const SkRect& rect) {
+GrTexture* SkBlurImageFilter::filterImageGPU(Proxy* proxy, GrTexture* src, const SkRect& rect) {
#if SK_SUPPORT_GPU
SkAutoTUnref<GrTexture> input(this->getInputResultAsTexture(proxy, src, rect));
return src->getContext()->gaussianBlur(input.get(), false, rect,
diff --git a/src/effects/SkMorphologyImageFilter.cpp b/src/effects/SkMorphologyImageFilter.cpp
index a497346b88..07b6449c33 100644
--- a/src/effects/SkMorphologyImageFilter.cpp
+++ b/src/effects/SkMorphologyImageFilter.cpp
@@ -482,12 +482,12 @@ GrTexture* apply_morphology(GrTexture* srcTexture,
};
-GrTexture* SkDilateImageFilter::onFilterImageGPU(Proxy* proxy, GrTexture* src, const SkRect& rect) {
+GrTexture* SkDilateImageFilter::filterImageGPU(Proxy* proxy, GrTexture* src, const SkRect& rect) {
SkAutoTUnref<GrTexture> input(this->getInputResultAsTexture(proxy, src, rect));
return apply_morphology(input, rect, GrMorphologyEffect::kDilate_MorphologyType, radius());
}
-GrTexture* SkErodeImageFilter::onFilterImageGPU(Proxy* proxy, GrTexture* src, const SkRect& rect) {
+GrTexture* SkErodeImageFilter::filterImageGPU(Proxy* proxy, GrTexture* src, const SkRect& rect) {
SkAutoTUnref<GrTexture> input(this->getInputResultAsTexture(proxy, src, rect));
return apply_morphology(input, rect, GrMorphologyEffect::kErode_MorphologyType, radius());
}
diff --git a/src/effects/SkBlendImageFilter.cpp b/src/effects/SkBlendImageFilter.cpp
index d2b9e73880..4e5e018d0f 100644
--- a/src/effects/SkBlendImageFilter.cpp
+++ b/src/effects/SkBlendImageFilter.cpp
@@ -172,8 +172,8 @@ static GrTexture* getInputResultAsTexture(SkImageFilter::Proxy* proxy,
if (!input) {
resultTex = src;
} else if (input->canFilterImageGPU()) {
- // onFilterImageGPU() already refs the result, so just return it here.
- return input->onFilterImageGPU(proxy, src, rect);
+ // filterImageGPU() already refs the result, so just return it here.
+ return input->filterImageGPU(proxy, src, rect);
} else {
SkBitmap srcBitmap, result;
srcBitmap.setConfig(SkBitmap::kARGB_8888_Config, src->width(), src->height());
@@ -196,7 +196,7 @@ static GrTexture* getInputResultAsTexture(SkImageFilter::Proxy* proxy,
return resultTex;
}
-GrTexture* SkBlendImageFilter::onFilterImageGPU(Proxy* proxy, GrTexture* src, const SkRect& rect) {
+GrTexture* SkBlendImageFilter::filterImageGPU(Proxy* proxy, GrTexture* src, const SkRect& rect) {
SkAutoTUnref<GrTexture> background(getInputResultAsTexture(proxy, getBackgroundInput(), src, rect));
SkAutoTUnref<GrTexture> foreground(getInputResultAsTexture(proxy, getForegroundInput(), src, rect));
GrContext* context = src->getContext();
diff --git a/src/effects/SkSingleInputImageFilter.cpp b/src/effects/SkSingleInputImageFilter.cpp
index 76150386f4..08d039ccfa 100644
--- a/src/effects/SkSingleInputImageFilter.cpp
+++ b/src/effects/SkSingleInputImageFilter.cpp
@@ -46,8 +46,8 @@ GrTexture* SkSingleInputImageFilter::getInputResultAsTexture(Proxy* proxy,
if (!input) {
resultTex = src;
} else if (input->canFilterImageGPU()) {
- // onFilterImageGPU() already refs the result, so just return it here.
- return input->onFilterImageGPU(proxy, src, rect);
+ // filterImageGPU() already refs the result, so just return it here.
+ return input->filterImageGPU(proxy, src, rect);
} else {
SkBitmap srcBitmap, result;
srcBitmap.setConfig(SkBitmap::kARGB_8888_Config, src->width(), src->height());